@@ -1,13 +1,12 @@
+use crate::shutdown_mux_master::shutdown_mux_master_from;
 use crate::{constants, Error, EstablishedSession, Response, Result, Session, Socket};
 
 use crate::raw_connection::RawConnection;
 use crate::request::{Fwd, Request};
 
-use core::convert::AsRef;
 use core::num::{NonZeroU32, Wrapping};
 
 use std::borrow::Cow;
-use std::io::Write;
 use std::path::Path;
 
 use serde::Deserialize;
@@ -396,15 +395,8 @@ impl Connection {
     /// and remove its listener socket.
     ///
     /// **Only suitable to use in `Drop::drop`.**
-    pub fn close(mut self) -> Result<()> {
-        let request_id = self.get_request_id();
-
-        self.raw_conn.into_std()?.write_all(
-            self.transformer
-                .serialize(&Request::StopListening { request_id })?,
-        )?;
-
-        Ok(())
+    pub fn close(self) -> Result<()> {
+        shutdown_mux_master_from(self.raw_conn.into_std()?, self.transformer)
     }
 }
 
