@@ -7,6 +7,7 @@ mod raw_connection;
 mod request;
 mod response;
 mod session;
+mod shutdown_mux_master;
 
 pub mod default_config;
 
@@ -20,6 +21,8 @@ pub use session::*;
 
 pub use connection::*;
 
+pub use shutdown_mux_master::shutdown_mux_master;
+
 #[cfg(test)]
 #[macro_use]
 extern crate assert_matches;
